Package {predHCS}


Type: Package
Title: Point and Interval Prediction for Censored Data under Various Hybrid Censoring Schemes
Version: 0.1.0
Maintainer: Shikhar Tyagi <shikhar1093tyagi@gmail.com>
Description: Implements generalized statistical point prediction and prediction intervals for future failure times under various hybrid censoring schemes. Supported censoring schemes include Type-I, Type-II, Generalized Type-I, Generalized Type-II, Unified, Progressive Type-I, and Progressive Type-II hybrid censoring schemes. Available prediction methods include Best Unbiased Predictor (BUP), Conditional Median Predictor (CMP), Maximum Likelihood Predictor (MLP), equal-tailed classical prediction intervals, Highest Conditional Density (HCD) prediction intervals, and Bayesian prediction intervals. Algorithms accept user-defined continuous probability density functions, cumulative distribution functions, quantile functions, or survival functions along with estimated parameter values. Methodological foundations are based on Balakrishnan, Cramer, and Kundu (2023, ISBN:978-0123983879), Shafay and Balakrishnan (2012) <doi:10.1080/03610918.2011.579367> for Type-I hybrid censoring, Balakrishnan and Shafay (2012) <doi:10.1080/03610926.2010.543300> for Type-II hybrid censoring, Shafay (2017) <doi:10.1080/03610926.2016.1200093> for Generalized Type-I hybrid censoring, Shafay (2016) <doi:10.1080/00949655.2015.1096361> for Generalized Type-II hybrid censoring, Mohie El-Din, Nagy, and Shafay (2017) <doi:10.18576/jsap/060113> for Unified hybrid censoring, Ebrahimi (1992) <doi:10.1109/24.126685>, Valiollahi, Asgharzadeh, and Kundu (2017) <doi:10.1214/15-BJPS302>, and Asgharzadeh, Valiollahi, and Kundu (2015) <doi:10.1080/00949655.2013.848451>.
License: GPL-3
Encoding: UTF-8
Depends: R (≥ 4.0.0)
Imports: stats, graphics
Suggests: testthat (≥ 3.0.0)
ByteCompile: true
NeedsCompilation: no
Packaged: 2026-07-27 16:10:11 UTC; shikhar tyagi
Author: Shikhar Tyagi ORCID iD [aut, cre], Arvind Pandey [aut], Bhupendra Singh [aut], Vrijesh Tripathi [aut]
Repository: CRAN
Date/Publication: 2026-08-05 09:20:09 UTC

Point and Interval Prediction for Censored Data under Various Hybrid Censoring Schemes

Description

Implements generalized statistical point prediction and prediction intervals for future failure times under various hybrid censoring schemes. Supported censoring schemes include Type-I, Type-II, Generalized Type-I, Generalized Type-II, Unified, Progressive Type-I, and Progressive Type-II hybrid censoring schemes.

Details

Package: predHCS
Type: Package
Version: 0.1.0
Date: 2026-07-25
License: GPL-3

The main function is predict_censored, which acts as a unified interface for point and interval prediction under any supported hybrid censoring scheme.

Author(s)

Shikhar Tyagi, Arvind Pandey, Bhupendra Singh, Vrijesh Tripathi

Maintainer: Shikhar Tyagi <shikhar1093tyagi@gmail.com>

References

Balakrishnan, N., Cramer, E., & Kundu, D. (2023). Hybrid censoring know-how: Designs and implementations. Academic Press.

Shafay, A. R., & Balakrishnan, N. (2012). One- and two-sample Bayesian prediction intervals based on Type-I hybrid censored data. Communications in Statistics - Theory and Methods, 41(1), 65-88.

Balakrishnan, N., & Shafay, A. R. (2012). One- and two-sample Bayesian prediction intervals based on Type-II hybrid censored data. Communications in Statistics - Theory and Methods, 41(8), 1411-1431.

Shafay, A. R. (2017). Bayesian estimation and prediction based on generalized Type-I hybrid censored sample. Communications in Statistics - Theory and Methods, 46(10), 4870-4887.

Shafay, A. R. (2016). Bayesian estimation and prediction based on generalized Type-II hybrid censored sample. Journal of Statistical Computation and Simulation, 86(10), 1970-1988.

Mohie El-Din, M. M., Nagy, M., & Shafay, A. R. (2017). Statistical inference under unified hybrid censoring scheme. Journal of Statistics Applications & Probability, 6(1), 149-167.

Ebrahimi, N. (1992). Prediction of failure times, given information on failure times of composite subsystems. Journal of Statistical Planning and Inference, 33(2), 241-256.

Valiollahi, R., Asgharzadeh, A., & Kundu, D. (2017). Prediction of future failures for generalized exponential distribution under Type-I or Type-II hybrid censoring. Brazilian Journal of Probability and Statistics, 31(1), 41-61.

Asgharzadeh, A., Valiollahi, R., & Raqab, M. Z. (2015). Stress-strength reliability of Weibull distribution under progressive Type-II censoring. Communications in Statistics - Theory and Methods, 44(8), 1618-1631.

Examples

data_obs <- c(0.5, 1.2, 2.1, 3.4, 4.0)
cdf_exp <- function(x, par) pexp(x, rate = par[1])
res <- predict_censored(data = data_obs, n = 10, scheme = "Type-I",
                        r = 6, T0 = 5.0, s = 1:2, cdf = cdf_exp, param = 0.5)
print(res)

S3 Methods for predhcs Objects

Description

Print, summary, and plot methods for objects of class predhcs.

Usage

## S3 method for class 'predhcs'
print(x, ...)

## S3 method for class 'predhcs'
summary(object, ...)

## S3 method for class 'predhcs'
plot(x, ...)

Arguments

x

An object of class predhcs.

object

An object of class predhcs.

...

Additional arguments.

Value

print and summary invisibly return the object. plot creates a graphical display.

Examples

data_obs <- c(0.4, 0.8, 1.3, 2.1, 3.0)
cdf_exp <- function(x, par) pexp(x, rate = par[1])
res <- pred_type1_hybrid(data = data_obs, n = 10, r = 6, T0 = 4.0, s = 1:2,
                         cdf = cdf_exp, param = 0.5)
print(res)
summary(res)
plot(res)

Unified Interface for Point and Interval Prediction under Hybrid Censoring

Description

Unified entry point function to perform point prediction (BUP, CMP, MLP, Bayesian) and interval prediction (Classical, HCD, Bayesian) under various hybrid censoring schemes.

Usage

predict_censored(data, n, scheme = c("Type-I", "Type-II", "Gen-Type-I",
  "Gen-Type-II", "Unified", "Prog-Type-I", "Prog-Type-II"), T0 = NULL,
  T1 = NULL, T2 = NULL, r = NULL, k = NULL, R = NULL, s = 1, cdf = NULL,
  pdf = NULL, qdf = NULL, surv = NULL, param = NULL, conf.level = 0.95,
  bayes.draws = NULL)

Arguments

data

Numeric vector of observed failure times.

n

Total initial sample size.

scheme

Character string specifying the hybrid censoring scheme.

T0

Pre-fixed termination or inspection time threshold.

T1

First time threshold for Unified scheme.

T2

Second time threshold for Unified scheme.

r

Target number of failures.

k

Lower threshold for failure count.

R

Numeric vector of progressive removals.

s

Integer or vector of integers specifying future failure steps to predict.

cdf

Optional user-defined cumulative distribution function.

pdf

Optional user-defined probability density function.

qdf

Optional user-defined quantile function.

surv

Optional user-defined survival function.

param

Parameter vector or list for the distribution.

conf.level

Confidence level for prediction intervals (default 0.95).

bayes.draws

Optional matrix of MCMC posterior draws for Bayesian prediction.

Value

An object of class predhcs containing prediction results.

Examples

data_obs <- c(0.4, 0.8, 1.3, 2.1, 3.0)
cdf_exp <- function(x, par) pexp(x, rate = par[1])
res1 <- predict_censored(data = data_obs, n = 10, scheme = "Type-I",
                        r = 6, T0 = 4.0, s = 1:2, cdf = cdf_exp, param = 0.5)
print(res1)

Specific Hybrid Censoring Scheme Prediction Functions

Description

Functions to compute point predictions and prediction intervals under specific hybrid censoring schemes.

Usage

pred_type1_hybrid(data, n, r, T0, s = 1, cdf = NULL, pdf = NULL, qdf = NULL,
  surv = NULL, param = NULL, conf.level = 0.95, bayes.draws = NULL)

pred_type2_hybrid(data, n, r, T0, s = 1, cdf = NULL, pdf = NULL, qdf = NULL,
  surv = NULL, param = NULL, conf.level = 0.95, bayes.draws = NULL)

pred_gen_type1_hybrid(data, n, k, r, T0, s = 1, cdf = NULL, pdf = NULL,
  qdf = NULL, surv = NULL, param = NULL, conf.level = 0.95, bayes.draws = NULL)

pred_gen_type2_hybrid(data, n, k, r, T0, s = 1, cdf = NULL, pdf = NULL,
  qdf = NULL, surv = NULL, param = NULL, conf.level = 0.95, bayes.draws = NULL)

pred_unified_hybrid(data, n, k, r, T1, T2, s = 1, cdf = NULL, pdf = NULL,
  qdf = NULL, surv = NULL, param = NULL, conf.level = 0.95, bayes.draws = NULL)

pred_prog_type1_hybrid(data, n, R, T0, s = 1, cdf = NULL, pdf = NULL,
  qdf = NULL, surv = NULL, param = NULL, conf.level = 0.95, bayes.draws = NULL)

pred_prog_type2_hybrid(data, n, R, T0, s = 1, cdf = NULL, pdf = NULL,
  qdf = NULL, surv = NULL, param = NULL, conf.level = 0.95, bayes.draws = NULL)

Arguments

data

Numeric vector of observed failure times.

n

Total initial sample size.

r

Target number of failures.

k

Lower threshold for failure count.

T0

Termination time threshold.

T1

First time threshold for Unified scheme.

T2

Second time threshold for Unified scheme.

R

Progressive removals vector.

s

Future failure step(s) to predict.

cdf

Optional user CDF.

pdf

Optional user PDF.

qdf

Optional user Quantile function.

surv

Optional user Survival function.

param

Distribution parameters.

conf.level

Confidence level for prediction intervals.

bayes.draws

Optional MCMC posterior draws matrix.

Value

An object of class predhcs containing prediction results.

Examples

data_obs <- c(0.5, 1.2, 2.1, 3.4, 4.0)
cdf_exp <- function(x, par) pexp(x, rate = par[1])
res <- pred_type1_hybrid(data = data_obs, n = 10, r = 6, T0 = 5.0, s = 1:2,
                         cdf = cdf_exp, param = 0.5)
print(res)

mirror server hosted at Truenetwork, Russian Federation.